
# Type: exposure event to phenotypic feature association_subject




URI: [biolink:exposure_event_to_phenotypic_feature_association_subject](https://w3id.org/biolink/vocab/exposure_event_to_phenotypic_feature_association_subject)


## Domain and Range

[ExposureEventToPhenotypicFeatureAssociation](ExposureEventToPhenotypicFeatureAssociation.md) ->  <sub>REQ</sub> [ExposureEvent](ExposureEvent.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [ExposureEventToPhenotypicFeatureAssociation](ExposureEventToPhenotypicFeatureAssociation.md)
